pub struct ExecutableRegion {
pub name: String,
pub address: u64,
pub size: u64,
pub vaddr: u64,
pub build_id: Vec<u8>,
}Expand description
A memory region containing code loaded from an ELF file.
Fields
name: StringRegion name for human consumption (usually either the ELF soname or the VMO name), if known.
address: u64The start address of this region.
size: u64Region size, in bytes.
vaddr: u64The address of the memory region relative to the file’s load address.
build_id: Vec<u8>The Build ID of the ELF file.